"""Wrapper for interacting with the Volkszahler API."""
import asyncio
import logging

import aiohttp
import async_timeout

from . import exceptions

_LOGGER = logging.getLogger(__name__)
_RESOURCE = "{schema}://{host}:{port}/middleware.php/data/{uuid}.json"


class Volkszaehler(object):
    """A class for handling the data retrieval."""

    def __init__(self, loop, session, uuid, host="localhost", port=80, tls=False):
        """Initialize the connection to the API."""
        self._loop = loop
        self._session = session
        if tls:
            self.url = _RESOURCE.format(schema="https", host=host, port=port, uuid=uuid)
        else:
            self.url = _RESOURCE.format(schema="http", host=host, port=port, uuid=uuid)
        self.data = {}
        self.average = self.max = self.min = self.consumption = None
        self.tuples = []

    async def get_data(self):
        """Retrieve the data."""
        try:
            with async_timeout.timeout(5, loop=self._loop):
                response = await self._session.get(self.url)

            _LOGGER.debug("Response from Volkszaehler API: %s", response.status)
            self.data = await response.json()
            _LOGGER.debug(self.data)
        except (asyncio.TimeoutError, aiohttp.ClientError):
            _LOGGER.error("Can not load data from Volkszaehler API")
            self.data = None
            raise exceptions.VolkszaehlerApiConnectionError()

        self.average = self.data["data"]["average"]
        self.max = self.data["data"]["max"][1]
        self.min = self.data["data"]["min"][1]
        self.consumption = self.data["data"]["consumption"]
        self.tuples = self.data["data"]["tuples"]



"""Exceptions for wrapper to interact with the Volkszahler API."""


class VolkszaehlerError(Exception):
    """General Volkszaehler Error exception occurred."""

    pass


class VolkszaehlerApiConnectionError(VolkszaehlerError):
    """When a connection error is encountered."""

    pass


class VolkszaehlerNoDataAvailable(VolkszaehlerError):
    """When no data is available."""

    pass



"""Sample code to use the wrapper for interacting with the Volkszaehler API."""
import asyncio

import aiohttp

from volkszaehler import Volkszaehler

HOST = "demo.volkszaehler.org"
UUID = "57acbef0-88a9-11e4-934f-6b0f9ecd95a8"


async def main():
    """The main part of the example script."""
    async with aiohttp.ClientSession() as session:
        zaehler = Volkszaehler(loop, session, UUID, host=HOST, port=443, tls=True)

        # Get the data
        await zaehler.get_data()

        print("Average:", zaehler.average)
        print("Max:", zaehler.max)
        print("Min:", zaehler.min)
        print("Consumption:", zaehler.consumption)
        print("Data tuples:", zaehler.tuples)


loop = asyncio.get_event_loop()
loop.run_until_complete(main())



#!/usr/bin/env python3
"""Script to set up the Volkszaehler API wrapper."""
import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

if sys.argv[-1] == 'publish':
    os.system('python3 setup.py sdist upload')
    sys.exit()

setup(
    name='volkszaehler',
    version='0.2.0',
    description='Python Wrapper for interacting with the Volkszahler API.',
    long_description=long_description,
    url='https://github.com/home-assistant-ecosystem/python-volkszaehler',
    download_url='https://github.com/home-assistant-ecosystem/python-volkszaehler/releases',
    author='Fabian Affolter',
    author_email='fabian@affolter-engineering.ch',
    license='MIT',
    install_requires=['aiohttp', 'async_timeout'],
    packages=['volkszaehler'],
    zip_safe=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Utilities',
    ],
)
